from enum import Enum

API_BASE_URL: str = "https://api.neuroio.com"
IAM_BASE_URL: str = "https://iam.neuroio.com"
HTTP_CLIENT_TIMEOUT: float = 4.0


sentinel = object()


class SourceLicense(str, Enum):
    BASIC = "basic"
    STANDARD = "standard"
    STANDARD_PLUS = "standard+"
    ADVANCED = "advanced"


class EntryResult(str, Enum):
    NEW = "new"
    REINIT = "reinit"
    EXACT = "exact"
    HA = "ha"
    JUNK = "junk"
    NM = "nm"
    DET = "det"


class EntryMood(str, Enum):
    NEUTRAL = "neutral"
    ANGER = "anger"
    CONTEMPT = "contempt"
    DISGUST = "disgust"
    FEAR = "fear"
    HAPPINESS = "happiness"
    SADNESS = "sadness"
    SURPRISE = "surprise"
    NM = "nm"
    DET = "det"


class EntryLiveness(str, Enum):
    PASSED = "passed"
    FAILED = "failed"
    UNDETERMINED = "undetermined"


class Sex(int, Enum):
    MALE = 0
    FEMALE = 1


class HttpMethod(int, Enum):
    POST = 0
    GET = 1


DEFAULT_EXACT_THRESHOLD = 79.3
DEFAULT_HA_THRESHOLD = 75.5
DEFAULT_JUNK_THRESHOLD = 68.84



from datetime import datetime
from typing import List, Union

from httpx import Response

from neuroio.api.base import APIBase, APIBaseAsync
from neuroio.constants import EntryLiveness, EntryMood, EntryResult, sentinel
from neuroio.utils import request_query_processing


class Entries(APIBase):
    def list(
        self,
        pid: Union[List[str], object] = sentinel,
        result: Union[List[EntryResult], object] = sentinel,
        age_from: Union[int, object] = sentinel,
        age_to: Union[int, object] = sentinel,
        sex: Union[int, object] = sentinel,
        mood: Union[List[EntryMood], object] = sentinel,
        liveness: Union[List[EntryLiveness], object] = sentinel,
        sources_ids: Union[List[int], object] = sentinel,
        spaces_ids: Union[List[int], object] = sentinel,
        date_from: Union[datetime, object] = sentinel,
        date_to: Union[datetime, object] = sentinel,
        limit: int = 20,
        offset: int = 0,
    ) -> Response:
        data = request_query_processing(locals(), ["self"])
        try:
            return self.client.get(url="/v1/entries/", params=data)
        finally:
            self.client.close()

    def get(self, pid: str) -> Response:
        try:
            return self.client.get(url=f"/v1/entries/stats/pid/{pid}/")
        finally:
            self.client.close()

    def delete(self, pid: str) -> Response:
        try:
            return self.client.delete(url=f"/v1/entries/{pid}/")
        finally:
            self.client.close()


class EntriesAsync(APIBaseAsync):
    async def list(
        self,
        pid: Union[List[str], object] = sentinel,
        result: Union[List[EntryResult], object] = sentinel,
        age_from: Union[int, object] = sentinel,
        age_to: Union[int, object] = sentinel,
        sex: Union[int, object] = sentinel,
        mood: Union[List[EntryMood], object] = sentinel,
        liveness: Union[List[EntryLiveness], object] = sentinel,
        sources_ids: Union[List[int], object] = sentinel,
        spaces_ids: Union[List[int], object] = sentinel,
        date_from: Union[datetime, object] = sentinel,
        date_to: Union[datetime, object] = sentinel,
        limit: int = 20,
        offset: int = 0,
    ) -> Response:
        data = request_query_processing(locals(), ["self"])
        try:
            return await self.client.get(url="/v1/entries/", params=data)
        finally:
            await self.client.aclose()

    async def get(self, pid: str) -> Response:
        try:
            return await self.client.get(url=f"/v1/entries/stats/pid/{pid}/")
        finally:
            await self.client.aclose()

    async def delete(self, pid: str) -> Response:
        try:
            return await self.client.delete(url=f"/v1/entries/{pid}/")
        finally:
            await self.client.aclose()



from typing import List, Union

from httpx import Response

from neuroio.api.base import APIBase, APIBaseAsync
from neuroio.constants import (
    EntryLiveness,
    EntryMood,
    EntryResult,
    HttpMethod,
    Sex,
    sentinel,
)
from neuroio.utils import request_dict_processing, request_query_processing


class Notifications(APIBase):
    def create(
        self,
        name: str,
        http_method: HttpMethod,
        destination_url: str,
        is_active: bool = True,
        moods: Union[List[EntryMood], object] = sentinel,
        results: Union[List[EntryResult], object] = sentinel,
        liveness: Union[List[EntryLiveness], object] = sentinel,
        age_from: Union[int, object] = sentinel,
        age_to: Union[int, object] = sentinel,
        sex: Union[List[Sex], object] = sentinel,
        sources: Union[List[int], object] = sentinel,
        persons_groups: Union[List[int], object] = sentinel,
    ) -> Response:
        data = request_dict_processing(locals(), ["self"])
        try:
            return self.client.post(url="/v1/notifications/", json=data)
        finally:
            self.client.close()

    def list(
        self,
        q: Union[str, object] = sentinel,
        spaces_ids: Union[List[int], object] = sentinel,
        limit: int = 20,
        offset: int = 0,
    ) -> Response:
        data = request_query_processing(locals(), ["self"])
        try:
            return self.client.get(url="/v1/notifications/", params=data)
        finally:
            self.client.close()

    def get(self, id: int) -> Response:
        try:
            return self.client.get(url=f"/v1/notifications/{id}/")
        finally:
            self.client.close()

    def update(
        self,
        id: int,
        name: str,
        http_method: HttpMethod,
        destination_url: str,
        is_active: bool = True,
        moods: Union[List[EntryMood], object] = sentinel,
        results: Union[List[EntryResult], object] = sentinel,
        liveness: Union[List[EntryLiveness], object] = sentinel,
        age_from: Union[int, object] = sentinel,
        age_to: Union[int, object] = sentinel,
        sex: Union[List[Sex], object] = sentinel,
        sources: Union[List[int], object] = sentinel,
        persons_groups: Union[List[int], object] = sentinel,
    ) -> Response:
        data = request_dict_processing(locals(), ["self", "id"])
        try:
            return self.client.patch(url=f"/v1/notifications/{id}/", json=data)
        finally:
            self.client.close()

    def delete(self, id: int) -> Response:
        try:
            return self.client.delete(url=f"/v1/notifications/{id}/")
        finally:
            self.client.close()


class NotificationsAsync(APIBaseAsync):
    async def create(
        self,
        name: str,
        http_method: HttpMethod,
        destination_url: str,
        is_active: bool = True,
        moods: Union[List[EntryMood], object] = sentinel,
        results: Union[List[EntryResult], object] = sentinel,
        liveness: Union[List[EntryLiveness], object] = sentinel,
        age_from: Union[int, object] = sentinel,
        age_to: Union[int, object] = sentinel,
        sex: Union[List[Sex], object] = sentinel,
        sources: Union[List[int], object] = sentinel,
        persons_groups: Union[List[int], object] = sentinel,
    ) -> Response:
        data = request_dict_processing(locals(), ["self"])
        try:
            return await self.client.post(url="/v1/notifications/", json=data)
        finally:
            await self.client.aclose()

    async def list(
        self,
        q: Union[str, object] = sentinel,
        spaces_ids: Union[List[int], object] = sentinel,
        limit: int = 20,
        offset: int = 0,
    ) -> Response:
        data = request_query_processing(locals(), ["self"])
        try:
            return await self.client.get(url="/v1/notifications/", params=data)
        finally:
            await self.client.aclose()

    async def get(self, id: int) -> Response:
        try:
            return await self.client.get(url=f"/v1/notifications/{id}/")
        finally:
            await self.client.aclose()

    async def update(
        self,
        id: int,
        name: str,
        http_method: HttpMethod,
        destination_url: str,
        is_active: bool = True,
        moods: Union[List[EntryMood], object] = sentinel,
        results: Union[List[EntryResult], object] = sentinel,
        liveness: Union[List[EntryLiveness], object] = sentinel,
        age_from: Union[int, object] = sentinel,
        age_to: Union[int, object] = sentinel,
        sex: Union[List[Sex], object] = sentinel,
        sources: Union[List[int], object] = sentinel,
        persons_groups: Union[List[int], object] = sentinel,
    ) -> Response:
        data = request_dict_processing(locals(), ["self", "id"])
        try:
            return await self.client.patch(
                url=f"/v1/notifications/{id}/", json=data
            )
        finally:
            await self.client.aclose()

    async def delete(self, id: int) -> Response:
        try:
            return await self.client.delete(url=f"/v1/notifications/{id}/")
        finally:
            await self.client.aclose()



import httpx
from httpx import URL, Response

from neuroio import constants
from neuroio.api.base import APIBase, APIBaseAsync


class Spaces(APIBase):
    def create(self, name: str) -> Response:
        data = {"name": name}
        try:
            return self.client.post(url="/v1/spaces/", json=data)
        finally:
            self.client.close()

    def list(
        self, q: str = None, limit: int = 20, offset: int = 0
    ) -> Response:
        data = {"q": q, "limit": limit, "offset": offset}
        try:
            return self.client.get(url="/v1/spaces/", params=data)
        finally:
            self.client.close()

    def get(self, id: int) -> Response:
        try:
            return self.client.get(url=f"/v1/spaces/{id}/")
        finally:
            self.client.close()

    def update(self, id: int, name: str) -> Response:
        data = {"name": name}
        try:
            return self.client.patch(url=f"/v1/spaces/{id}/", json=data)
        finally:
            self.client.close()

    def delete(self, id: int) -> Response:
        try:
            return self.client.delete(url=f"/v1/spaces/{id}/")
        finally:
            self.client.close()

    def token(self, id: int, permanent: bool = False) -> Response:
        data = {"permanent": permanent}
        try:
            return self.client.post(url=f"/v1/spaces/{id}/tokens/", json=data)
        finally:
            self.client.close()


class SpacesAsync(APIBaseAsync):
    def __init__(self, client: httpx.AsyncClient):
        client.base_url = URL(constants.IAM_BASE_URL)
        super().__init__(client=client)

    async def create(self, name: str) -> Response:
        data = {"name": name}
        try:
            return await self.client.post(url="/v1/spaces/", json=data)
        finally:
            await self.client.aclose()

    async def list(
        self, q: str = None, limit: int = 20, offset: int = 0
    ) -> Response:
        data = {"q": q, "limit": limit, "offset": offset}
        try:
            return await self.client.get(url="/v1/spaces/", params=data)
        finally:
            await self.client.aclose()

    async def get(self, id: int) -> Response:
        try:
            return await self.client.get(url=f"/v1/spaces/{id}/")
        finally:
            await self.client.aclose()

    async def update(self, id: int, name: str) -> Response:
        data = {"name": name}
        try:
            return await self.client.patch(url=f"/v1/spaces/{id}/", json=data)
        finally:
            await self.client.aclose()

    async def delete(self, id: int) -> Response:
        try:
            return await self.client.delete(url=f"/v1/spaces/{id}/")
        finally:
            await self.client.aclose()

    async def token(self, id: int, permanent: bool = False) -> Response:
        data = {"permanent": permanent}
        try:
            return await self.client.post(
                url=f"/v1/spaces/{id}/tokens/", json=data
            )
        finally:
            await self.client.aclose()



"""**neuroio-python**

A Python package for interacting with the NeuroIO API
"""
from .clients import AsyncClient, Client

__version__: str = "0.0.1"

__all__ = ["__version__", "Client", "AsyncClient"]



from typing import List, Union

from httpx import Response

from neuroio.api.base import APIBase, APIBaseAsync
from neuroio.constants import sentinel
from neuroio.utils import request_query_processing


class Groups(APIBase):
    def create(self, name: str) -> Response:
        data = {"name": name}
        try:
            return self.client.post(url="/v1/groups/persons/", json=data)
        finally:
            self.client.close()

    def list(
        self,
        q: Union[str, object] = sentinel,
        pids_include: Union[List[str], object] = sentinel,
        pids_exclude: Union[List[str], object] = sentinel,
        groups_ids: Union[List[int], object] = sentinel,
        spaces_ids: Union[List[int], object] = sentinel,
        limit: int = 20,
        offset: int = 0,
    ) -> Response:
        data = request_query_processing(locals(), ["self"])
        try:
            return self.client.get(url="/v1/groups/persons/", params=data)
        finally:
            self.client.close()

    def get(self, id: int) -> Response:
        try:
            return self.client.get(url=f"/v1/groups/persons/{id}/")
        finally:
            self.client.close()

    def update(self, id: int, name: str) -> Response:
        data = {"name": name}
        try:
            return self.client.patch(
                url=f"/v1/groups/persons/{id}/", json=data
            )
        finally:
            self.client.close()

    def delete(self, id: int) -> Response:
        try:
            return self.client.delete(url=f"/v1/groups/persons/{id}/")
        finally:
            self.client.close()

    def persons(
        self,
        id: int,
        pids: Union[List[str], object] = sentinel,
        limit: int = 20,
        offset: int = 0,
    ) -> Response:
        data = request_query_processing(locals(), ["self", "id"])

        try:
            return self.client.get(
                url=f"/v1/groups/persons/{id}/pids/", params=data
            )
        finally:
            self.client.close()

    def add(self, pids: List[str], groups_ids: List[int]) -> Response:
        data = {"pids": pids, "groups_ids": groups_ids}
        try:
            return self.client.post(url="/v1/groups/persons/pids/", json=data)
        finally:
            self.client.close()

    def remove(self, pids: List[str], groups_ids: List[int]) -> Response:
        data = {"pids": pids, "groups_ids": groups_ids}
        try:
            return self.client.request(
                "DELETE", url="/v1/groups/persons/pids/", json=data
            )
        finally:
            self.client.close()


class GroupsAsync(APIBaseAsync):
    async def create(self, name: str) -> Response:
        data = {"name": name}
        try:
            return await self.client.post(url="/v1/groups/persons/", json=data)
        finally:
            await self.client.aclose()

    async def list(
        self,
        q: Union[str, object] = sentinel,
        pids_include: Union[List[str], object] = sentinel,
        pids_exclude: Union[List[str], object] = sentinel,
        groups_ids: Union[List[int], object] = sentinel,
        spaces_ids: Union[List[int], object] = sentinel,
        limit: int = 20,
        offset: int = 0,
    ) -> Response:
        data = request_query_processing(locals(), ["self"])
        try:
            return await self.client.get(
                url="/v1/groups/persons/", params=data
            )
        finally:
            await self.client.aclose()

    async def get(self, id: int) -> Response:
        try:
            return await self.client.get(url=f"/v1/groups/persons/{id}/")
        finally:
            await self.client.aclose()

    async def update(self, id: int, name: str) -> Response:
        data = {"name": name}
        try:
            return await self.client.patch(
                url=f"/v1/groups/persons/{id}/", json=data
            )
        finally:
            await self.client.aclose()

    async def delete(self, id: int) -> Response:
        try:
            return await self.client.delete(url=f"/v1/groups/persons/{id}/")
        finally:
            await self.client.aclose()

    async def persons(
        self,
        id: int,
        pids: Union[List[str], object] = sentinel,
        limit: int = 20,
        offset: int = 0,
    ) -> Response:
        data = request_query_processing(locals(), ["self", "id"])
        try:
            return await self.client.get(
                url=f"/v1/groups/persons/{id}/pids/", params=data
            )
        finally:
            await self.client.aclose()

    async def add(self, pids: List[str], groups_ids: List[int]) -> Response:
        data = {"pids": pids, "groups_ids": groups_ids}
        try:
            return await self.client.post(
                url="/v1/groups/persons/pids/", json=data
            )
        finally:
            await self.client.aclose()

    async def remove(self, pids: List[str], groups_ids: List[int]) -> Response:
        data = {"pids": pids, "groups_ids": groups_ids}
        try:
            return await self.client.request(
                "DELETE", url="/v1/groups/persons/pids/", json=data
            )
        finally:
            await self.client.aclose()



import typing

from httpx import Auth, Request, Response


class AuthorizationTokenAuth(Auth):
    """Describes an API Token requests authentication."""

    def __init__(self, api_token: str, header_name: str = None):
        """
        :param api_token: The API token that will be sent.
        :param header_name: Name of the header field.
        """
        self.api_token = api_token
        self.header_name = header_name or "Authorization"

    def auth_flow(
        self, request: Request
    ) -> typing.Generator[Request, Response, None]:
        request.headers[self.header_name] = f"Token {self.api_token}"
        yield request



from typing import List, Optional, Union

from httpx import Response

from neuroio.api.base import APIBase, APIBaseAsync
from neuroio.constants import SourceLicense, sentinel
from neuroio.utils import request_dict_processing, request_query_processing


class Sources(APIBase):
    def create(
        self,
        name: str,
        license_type: SourceLicense = SourceLicense.BASIC,
        identify_facesize_threshold: int = 7000,
        use_pps_time: bool = False,
        manual_create_facesize_threshold: int = 25000,
        manual_create_on_ha: bool = False,
        manual_create_on_junk: bool = False,
        manual_identify_asm: bool = True,
        auto_create_persons: bool = False,
        auto_create_facesize_threshold: int = 25000,
        auto_create_check_blur: bool = True,
        auto_create_check_exposure: bool = True,
        auto_create_on_ha: bool = False,
        auto_create_on_junk: bool = False,
        auto_check_face_angle: bool = True,
        auto_check_liveness: bool = False,
        auto_create_liveness_only: bool = True,
        auto_identify_asm: bool = True,
        store_images_for_results: Union[
            Optional[List[str]], object
        ] = sentinel,
    ) -> Response:
        data = request_dict_processing(locals(), ["self"])
        try:
            return self.client.post(url="/v1/sources/", json=data)
        finally:
            self.client.close()

    def list(
        self,
        q: str = None,
        spaces_ids: Union[List[int], object] = sentinel,
        limit: int = 20,
        offset: int = 0,
    ) -> Response:
        data = request_query_processing(locals(), ["self"])

        try:
            return self.client.get(url="/v1/sources/", params=data)
        finally:
            self.client.close()

    def get(self, id: int) -> Response:
        try:
            return self.client.get(url=f"/v1/sources/{id}/")
        finally:
            self.client.close()

    def update(
        self,
        id: int,
        name: str,
        license_type: Union[SourceLicense, object] = sentinel,
        identify_facesize_threshold: Union[int, object] = sentinel,
        use_pps_time: Union[bool, object] = sentinel,
        manual_create_facesize_threshold: Union[int, object] = sentinel,
        manual_create_on_ha: Union[bool, object] = sentinel,
        manual_create_on_junk: Union[bool, object] = sentinel,
        manual_identify_asm: Union[bool, object] = sentinel,
        auto_create_persons: Union[bool, object] = sentinel,
        auto_create_facesize_threshold: Union[int, object] = sentinel,
        auto_create_check_blur: Union[bool, object] = sentinel,
        auto_create_check_exposure: Union[bool, object] = sentinel,
        auto_create_on_ha: Union[bool, object] = sentinel,
        auto_create_on_junk: Union[bool, object] = sentinel,
        auto_check_face_angle: Union[bool, object] = sentinel,
        auto_check_liveness: Union[bool, object] = sentinel,
        auto_create_liveness_only: Union[bool, object] = sentinel,
        auto_identify_asm: Union[bool, object] = sentinel,
        store_images_for_results: Union[List[str], object] = sentinel,
    ) -> Response:
        data = request_dict_processing(locals(), ["id", "self"])

        try:
            return self.client.patch(url=f"/v1/sources/{id}/", json=data)
        finally:
            self.client.close()

    def delete(self, id: int) -> Response:
        try:
            return self.client.delete(url=f"/v1/sources/{id}/")
        finally:
            self.client.close()


class SourcesAsync(APIBaseAsync):
    async def create(
        self,
        name: str,
        license_type: SourceLicense = SourceLicense.BASIC,
        identify_facesize_threshold: int = 7000,
        use_pps_time: bool = False,
        manual_create_facesize_threshold: int = 25000,
        manual_create_on_ha: bool = False,
        manual_create_on_junk: bool = False,
        manual_identify_asm: bool = True,
        auto_create_persons: bool = False,
        auto_create_facesize_threshold: int = 25000,
        auto_create_check_blur: bool = True,
        auto_create_check_exposure: bool = True,
        auto_create_on_ha: bool = False,
        auto_create_on_junk: bool = False,
        auto_check_face_angle: bool = True,
        auto_check_liveness: bool = False,
        auto_create_liveness_only: bool = True,
        auto_identify_asm: bool = True,
        store_images_for_results: Union[
            Optional[List[str]], object
        ] = sentinel,
    ) -> Response:
        data = request_dict_processing(locals(), ["self"])
        try:
            return await self.client.post(url="/v1/sources/", json=data)
        finally:
            await self.client.aclose()

    async def list(
        self,
        q: str = None,
        spaces_ids: Union[List[int], object] = sentinel,
        limit: int = 20,
        offset: int = 0,
    ) -> Response:
        data = request_query_processing(locals(), ["self"])

        try:
            return await self.client.get(url="/v1/sources/", params=data)
        finally:
            await self.client.aclose()

    async def get(self, id: int) -> Response:
        try:
            return await self.client.get(url=f"/v1/sources/{id}/")
        finally:
            await self.client.aclose()

    async def update(
        self,
        id: int,
        name: str,
        license_type: Union[SourceLicense, object] = sentinel,
        identify_facesize_threshold: Union[int, object] = sentinel,
        use_pps_time: Union[bool, object] = sentinel,
        manual_create_facesize_threshold: Union[int, object] = sentinel,
        manual_create_on_ha: Union[bool, object] = sentinel,
        manual_create_on_junk: Union[bool, object] = sentinel,
        manual_identify_asm: Union[bool, object] = sentinel,
        auto_create_persons: Union[bool, object] = sentinel,
        auto_create_facesize_threshold: Union[int, object] = sentinel,
        auto_create_check_blur: Union[bool, object] = sentinel,
        auto_create_check_exposure: Union[bool, object] = sentinel,
        auto_create_on_ha: Union[bool, object] = sentinel,
        auto_create_on_junk: Union[bool, object] = sentinel,
        auto_check_face_angle: Union[bool, object] = sentinel,
        auto_check_liveness: Union[bool, object] = sentinel,
        auto_create_liveness_only: Union[bool, object] = sentinel,
        auto_identify_asm: Union[bool, object] = sentinel,
        store_images_for_results: Union[List[str], object] = sentinel,
    ) -> Response:
        data = request_dict_processing(locals(), ["id", "self"])

        try:
            return await self.client.patch(url=f"/v1/sources/{id}/", json=data)
        finally:
            await self.client.aclose()

    async def delete(self, id: int) -> Response:
        try:
            return await self.client.delete(url=f"/v1/sources/{id}/")
        finally:
            await self.client.aclose()



from httpx import Response

from neuroio.api.base import APIBase, APIBaseAsync
from neuroio.constants import (
    DEFAULT_EXACT_THRESHOLD,
    DEFAULT_HA_THRESHOLD,
    DEFAULT_JUNK_THRESHOLD,
)
from neuroio.utils import request_dict_processing


class Settings(APIBase):
    def get(self) -> Response:
        try:
            return self.client.get(url="/v1/settings/thresholds/")
        finally:
            self.client.close()

    def update(
        self,
        exact: float = DEFAULT_EXACT_THRESHOLD,
        ha: float = DEFAULT_HA_THRESHOLD,
        junk: float = DEFAULT_JUNK_THRESHOLD,
    ) -> Response:
        data = request_dict_processing(locals(), ["self"])

        try:
            return self.client.patch(url="/v1/settings/thresholds/", data=data)
        finally:
            self.client.close()

    def reset(self) -> Response:
        try:
            return self.client.post(url="/v1/settings/thresholds/reset/")
        finally:
            self.client.close()


class SettingsAsync(APIBaseAsync):
    async def get(self) -> Response:
        try:
            return await self.client.get(url="/v1/settings/thresholds/")
        finally:
            await self.client.aclose()

    async def update(
        self,
        exact: float = DEFAULT_EXACT_THRESHOLD,
        ha: float = DEFAULT_HA_THRESHOLD,
        junk: float = DEFAULT_JUNK_THRESHOLD,
    ) -> Response:
        data = request_dict_processing(locals(), ["self"])

        try:
            return await self.client.patch(
                url="/v1/settings/thresholds/", data=data
            )
        finally:
            await self.client.aclose()

    async def reset(self) -> Response:
        try:
            return await self.client.post(url="/v1/settings/thresholds/reset/")
        finally:
            await self.client.aclose()



from typing import Union

from httpx import Response

from neuroio.api.base import APIBase, APIBaseAsync


class Tokens(APIBase):
    def create(self, permanent: bool = False) -> Response:
        data = {"permanent": permanent}
        try:
            return self.client.post(url="/v1/tokens/", json=data)
        finally:
            self.client.close()

    def list(
        self, permanent: bool = None, limit: int = 20, offset: int = 0
    ) -> Response:
        data = {"permanent": permanent, "limit": limit, "offset": offset}
        try:
            return self.client.get(url="/v1/tokens/", params=data)
        finally:
            self.client.close()

    def get(self, token_id_or_key: Union[int, str]) -> Response:
        try:
            return self.client.get(url=f"/v1/tokens/{token_id_or_key}/")
        finally:
            self.client.close()

    def update(
        self, token_id_or_key: Union[int, str], is_active: bool
    ) -> Response:
        try:
            return self.client.patch(
                url=f"/v1/tokens/{token_id_or_key}/",
                data={"is_active": is_active},
            )
        finally:
            self.client.close()

    def delete_list(self, permanent: bool = None) -> Response:
        data = {"permanent": permanent} if permanent is not None else None
        try:
            return self.client.delete(url="/v1/tokens/", params=data)
        finally:
            self.client.close()

    def delete(self, token_id_or_key: Union[int, str]) -> Response:
        try:
            return self.client.delete(url=f"/v1/tokens/{token_id_or_key}/")
        finally:
            self.client.close()


class TokensAsync(APIBaseAsync):
    async def create(self, permanent: bool = False) -> Response:
        data = {"permanent": permanent}
        try:
            return await self.client.post(url="/v1/tokens/", json=data)
        finally:
            await self.client.aclose()

    async def list(
        self, permanent: bool = None, limit: int = 20, offset: int = 0
    ) -> Response:
        data = {"permanent": permanent, "limit": limit, "offset": offset}
        try:
            return await self.client.get(url="/v1/tokens/", params=data)
        finally:
            await self.client.aclose()

    async def get(self, token_id_or_key: Union[int, str]) -> Response:
        try:
            return await self.client.get(url=f"/v1/tokens/{token_id_or_key}/")
        finally:
            await self.client.aclose()

    async def update(
        self, token_id_or_key: Union[int, str], is_active: bool
    ) -> Response:
        try:
            return await self.client.patch(
                url=f"/v1/tokens/{token_id_or_key}/",
                data={"is_active": is_active},
            )
        finally:
            await self.client.aclose()

    async def delete_list(self, permanent: bool = None) -> Response:
        data = {"permanent": permanent} if permanent is not None else None
        try:
            return await self.client.delete(url="/v1/tokens/", params=data)
        finally:
            await self.client.aclose()

    async def delete(self, token_id_or_key: Union[int, str]) -> Response:
        try:
            return await self.client.delete(
                url=f"/v1/tokens/{token_id_or_key}/"
            )
        finally:
            await self.client.aclose()



import abc

import httpx


class APIBase(abc.ABC):
    def __init__(self, client: httpx.Client) -> None:
        self.client = client


class APIBaseAsync(abc.ABC):
    def __init__(self, client: httpx.AsyncClient) -> None:
        self.client = client



from httpx import Response

from neuroio.api.base import APIBase, APIBaseAsync


class Whoami(APIBase):
    def me(self) -> Response:
        try:
            return self.client.get(url="/v1/whoami/")
        finally:
            self.client.close()


class WhoamiAsync(APIBaseAsync):
    async def me(self) -> Response:
        try:
            return await self.client.get(url="/v1/whoami/")
        finally:
            await self.client.aclose()



import enum
from typing import Optional, Type, Union

import httpx

from neuroio import constants
from neuroio.api.base import APIBase
from neuroio.auth import AuthorizationTokenAuth
from neuroio.utils import cached_property, dynamic_import, get_package_version


class Service(str, enum.Enum):
    API = "api"
    IAM = "iam"


class Client:
    def __init__(
        self,
        api_token: Optional[str] = None,
        api_version: int = 1,
        timeout: Optional[float] = None,
    ):
        """
        Creates and manages singleton of HTTP client, that is used to make
        request to API.
        """
        self.api_token = api_token
        self.api_version = api_version
        self.api_client = self.httpx_client_class(
            base_url=constants.API_BASE_URL,
            headers=self.common_headers,
            timeout=timeout or constants.HTTP_CLIENT_TIMEOUT,
        )
        self.iam_client = self.httpx_client_class(
            base_url=constants.IAM_BASE_URL,
            headers=self.common_headers,
            timeout=timeout or constants.HTTP_CLIENT_TIMEOUT,
        )
        self.inject_api_token()

    @property
    def httpx_client_class(
        self,
    ) -> Union[Type[httpx.Client], Type[httpx.AsyncClient]]:
        return httpx.Client

    @property
    def common_headers(self) -> dict:
        return {"User-Agent": f"neuroio-python/{get_package_version()}"}

    def inject_api_token(self, api_token: Optional[str] = None) -> None:
        # Override api token only if provided api_token is not empty or None
        if api_token:
            self.api_token = api_token

        # Injecting auth only if api_token is not empty or None
        if self.api_token:
            self.api_client.auth = AuthorizationTokenAuth(
                api_token=self.api_token
            )
            self.iam_client.auth = AuthorizationTokenAuth(
                api_token=self.api_token
            )

    def get_api_class_instance(
        self, namespace: str, clsname: str, service: Service = Service.API
    ) -> APIBase:
        abs_path = f"neuroio.{service}.{namespace}.v{self.api_version}"
        cls = dynamic_import(abs_path=abs_path, attribute=clsname)
        if service == Service.API:
            return cls(client=self.api_client)
        return cls(client=self.iam_client)

    @cached_property
    def auth(self) -> APIBase:
        return self.get_api_class_instance(
            namespace="auth", clsname="Auth", service=Service.IAM
        )

    @cached_property
    def sources(self) -> APIBase:
        return self.get_api_class_instance(
            namespace="sources", clsname="Sources"
        )

    @cached_property
    def entries(self) -> APIBase:
        return self.get_api_class_instance(
            namespace="entries", clsname="Entries"
        )

    @cached_property
    def utility(self) -> APIBase:
        return self.get_api_class_instance(
            namespace="utility", clsname="Utility"
        )

    @cached_property
    def settings(self) -> APIBase:
        return self.get_api_class_instance(
            namespace="settings", clsname="Settings"
        )

    @cached_property
    def groups(self) -> APIBase:
        return self.get_api_class_instance(
            namespace="groups", clsname="Groups"
        )

    @cached_property
    def persons(self) -> APIBase:
        return self.get_api_class_instance(
            namespace="persons", clsname="Persons"
        )

    @cached_property
    def notifications(self) -> APIBase:
        return self.get_api_class_instance(
            namespace="notifications", clsname="Notifications"
        )

    @cached_property
    def spaces(self) -> APIBase:
        return self.get_api_class_instance(
            namespace="spaces", clsname="Spaces", service=Service.IAM
        )

    @cached_property
    def whoami(self) -> APIBase:
        return self.get_api_class_instance(
            namespace="whoami", clsname="Whoami", service=Service.IAM
        )

    @cached_property
    def tokens(self) -> APIBase:
        return self.get_api_class_instance(
            namespace="tokens", clsname="Tokens", service=Service.IAM
        )


class AsyncClient(Client):
    @property
    def httpx_client_class(
        self,
    ) -> Union[Type[httpx.Client], Type[httpx.AsyncClient]]:
        return httpx.AsyncClient

    @property
    def common_headers(self) -> dict:
        return {"User-Agent": f"neuroio-async-python/{get_package_version()}"}

    @cached_property
    def auth(self) -> APIBase:
        return self.get_api_class_instance(
            namespace="auth", clsname="AuthAsync", service=Service.IAM
        )

    @cached_property
    def sources(self) -> APIBase:
        return self.get_api_class_instance(
            namespace="sources", clsname="SourcesAsync"
        )

    @cached_property
    def entries(self) -> APIBase:
        return self.get_api_class_instance(
            namespace="entries", clsname="EntriesAsync"
        )

    @cached_property
    def utility(self) -> APIBase:
        return self.get_api_class_instance(
            namespace="utility", clsname="UtilityAsync"
        )

    @cached_property
    def settings(self) -> APIBase:
        return self.get_api_class_instance(
            namespace="settings", clsname="SettingsAsync"
        )

    @cached_property
    def groups(self) -> APIBase:
        return self.get_api_class_instance(
            namespace="groups", clsname="GroupsAsync"
        )

    @cached_property
    def persons(self) -> APIBase:
        return self.get_api_class_instance(
            namespace="persons", clsname="PersonsAsync"
        )

    @cached_property
    def notifications(self) -> APIBase:
        return self.get_api_class_instance(
            namespace="notifications", clsname="NotificationsAsync"
        )

    @cached_property
    def spaces(self) -> APIBase:
        return self.get_api_class_instance(
            namespace="spaces", clsname="SpacesAsync", service=Service.IAM
        )

    @cached_property
    def whoami(self) -> APIBase:
        return self.get_api_class_instance(
            namespace="whoami", clsname="WhoamiAsync", service=Service.IAM
        )

    @cached_property
    def tokens(self) -> APIBase:
        return self.get_api_class_instance(
            namespace="tokens", clsname="TokensAsync", service=Service.IAM
        )



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['neuroio',
 'neuroio.api',
 'neuroio.api.entries',
 'neuroio.api.groups',
 'neuroio.api.notifications',
 'neuroio.api.persons',
 'neuroio.api.settings',
 'neuroio.api.sources',
 'neuroio.api.utility',
 'neuroio.iam',
 'neuroio.iam.auth',
 'neuroio.iam.spaces',
 'neuroio.iam.tokens',
 'neuroio.iam.whoami']

package_data = \
{'': ['*']}

install_requires = \
['httpx>=0.13.3,<0.14.0']

setup_kwargs = {
    'name': 'neuroio',
    'version': '0.0.2',
    'description': 'A Python package for interacting with NeuroIO API',
    'long_description': 'neuroio-python\n_________________\n\n[![PyPI version](https://badge.fury.io/py/neuroio.svg)](http://badge.fury.io/py/neuroio)\n[![codecov](https://codecov.io/gh/neuroio/neuroio-python/branch/master/graph/badge.svg)](https://codecov.io/gh/neuroio/neuroio-python)\n[![License](https://img.shields.io/github/license/mashape/apistatus.svg)](https://pypi.python.org/pypi/neuroio/)\n[![Downloads](https://pepy.tech/badge/neuroio)](https://pepy.tech/project/neuroio)\n[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)\n[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://timothycrosley.github.io/isort/)\n\n_________________\n\n[Read Latest Documentation](https://neuroio.github.io/neuroio-python/) - [Browse GitHub Code Repository](https://github.com/neuroio/neuroio-python/)\n_________________\n\n**neuroio-python** A Python package for interacting with NeuroIO API\n',
    'author': 'Lev Rubel',
    'author_email': 'l@datacorp.ee',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)



from httpx import Response

from neuroio.api.base import APIBase, APIBaseAsync


class Auth(APIBase):
    def login(self, username: str, password: str) -> Response:
        data = {"username": username, "password": password}
        try:
            return self.client.post(url="/v1/login/", json=data)
        finally:
            self.client.close()

    def password_change(
        self, old_password: str, new_password: str, reset_tokens: bool = False
    ) -> Response:
        data = {
            "old_password": old_password,
            "password": new_password,
            "password2": new_password,
            "reset_tokens": reset_tokens,
        }
        try:
            return self.client.post(url="/v1/auth/password/change/", json=data)
        finally:
            self.client.close()


class AuthAsync(APIBaseAsync):
    async def login(self, username: str, password: str) -> Response:
        data = {"username": username, "password": password}
        try:
            return await self.client.post(url="/v1/login/", json=data)
        finally:
            await self.client.aclose()

    async def password_change(
        self, old_password: str, new_password: str, reset_tokens: bool = False
    ) -> Response:
        data = {
            "old_password": old_password,
            "password": new_password,
            "password2": new_password,
            "reset_tokens": reset_tokens,
        }
        try:
            return await self.client.post(
                url="/v1/auth/password/change/", json=data
            )
        finally:
            await self.client.aclose()



from typing.io import BinaryIO

from httpx import Response

from neuroio.api.base import APIBase, APIBaseAsync
from neuroio.constants import EntryResult


class Utility(APIBase):
    def compare(
        self, image1: BinaryIO, image2: BinaryIO, result: str = EntryResult.HA
    ) -> Response:
        files = {"image1": image1, "image2": image2}
        data = {"result": result}
        try:
            return self.client.post(
                url="/v1/utility/compare/", data=data, files=files
            )
        finally:
            self.client.close()

    def asm(self, image: BinaryIO) -> Response:
        files = {"image": image}
        try:
            return self.client.post(url="/v1/utility/asm/", files=files)
        finally:
            self.client.close()


class UtilityAsync(APIBaseAsync):
    async def compare(
        self, image1: BinaryIO, image2: BinaryIO, result: str = EntryResult.HA
    ) -> Response:
        files = {"image1": image1, "image2": image2}
        data = {"result": result}
        try:
            return await self.client.post(
                url="/v1/utility/compare/", data=data, files=files
            )
        finally:
            await self.client.aclose()

    async def asm(self, image: BinaryIO) -> Response:
        files = {"image": image}
        try:
            return await self.client.post(url="/v1/utility/asm/", files=files)
        finally:
            await self.client.aclose()



import functools
from importlib import import_module
from typing import Any, Callable, List, Optional, TypeVar, Union

from neuroio.constants import sentinel


def get_package_version() -> str:
    from neuroio import __version__

    return __version__


def dynamic_import(abs_path: str, attribute: str) -> Any:
    """
    Imports any attribute from the module specified as string dotted path.
    Takes into account current supplied version to the Client instance.

    :param abs_path: dotted path of the module from which to import from
    :param attribute: function, class or any other attr to be imported
    :return: imported attribute
    """
    module_object = import_module(abs_path)
    return getattr(module_object, attribute)


F = TypeVar("F", bound=Callable[..., Any])


def cached_property(f: F) -> property:
    return property(functools.lru_cache()(f))


def process_query_params(params: dict) -> dict:
    for key, item in params.items():
        if isinstance(item, list):
            params[key] = ",".join(map(str, item))
    return params


def request_dict_processing(
    local_items: dict, exclude: Optional[List[str]] = None
) -> dict:
    inner_exclude: List[str] = ["self"]
    if exclude is not None:
        inner_exclude.extend(exclude)

    return dict(
        filter(
            lambda kwarg: kwarg[1] is not sentinel
            and kwarg[0] not in inner_exclude,
            local_items.items(),
        )
    )


def request_query_processing(
    local_items: dict, exclude: Union[List[str], None] = None
) -> dict:
    if exclude is None:
        exclude = []
    return process_query_params(request_dict_processing(local_items, exclude))


def request_form_processing(
    local_items: dict, exclude: Union[List[str], None] = None
) -> dict:
    if exclude is None:
        exclude = []
    return {
        key: str(value)
        for key, value in request_dict_processing(local_items, exclude).items()
    }



from typing import BinaryIO, Union

from httpx import Response

from neuroio.api.base import APIBase, APIBaseAsync
from neuroio.constants import EntryResult, sentinel
from neuroio.utils import request_dict_processing, request_form_processing


class Persons(APIBase):
    def create(
        self,
        image: BinaryIO,
        source: str,
        facesize: Union[int, object] = sentinel,
        create_on_ha: Union[bool, object] = sentinel,
        create_on_junk: Union[bool, object] = sentinel,
        identify_asm: Union[bool, object] = sentinel,
    ) -> Response:
        data = request_form_processing(locals(), ["self", "image"])
        files = {"image": image}
        try:
            return self.client.post(url="/v1/persons/", data=data, files=files)
        finally:
            self.client.close()

    def create_by_entry(
        self, id: int, create_on_ha: bool, create_on_junk: bool
    ) -> Response:
        data = request_dict_processing(locals(), ["self"])

        try:
            return self.client.post(url="/v1/persons/entry/", json=data)
        finally:
            self.client.close()

    def reinit(self, id: int) -> Response:
        try:
            return self.client.post(url="/v1/persons/reinit/", json={"id": id})
        finally:
            self.client.close()

    def reinit_by_photo(
        self,
        pid: str,
        image: BinaryIO,
        source: str,
        facesize: Union[int, object] = sentinel,
        identify_asm: Union[bool, object] = sentinel,
        result: str = EntryResult.HA,
    ) -> Response:
        data = request_form_processing(locals())
        files = {"image": image}
        try:
            return self.client.post(
                url=f"/v1/persons/reinit/{pid}/", data=data, files=files
            )
        finally:
            self.client.close()

    def search(self, image: BinaryIO, identify_asm: bool = False) -> Response:
        files = {"image": ("image", image, "image/jpeg")}
        data = {"identify_asm": str(identify_asm)}
        try:
            return self.client.post(
                url="/v1/persons/search/", data=data, files=files
            )
        finally:
            self.client.close()

    def delete(self, pid: str) -> Response:
        try:
            return self.client.delete(url=f"/v1/persons/{pid}/")
        finally:
            self.client.close()


class PersonsAsync(APIBaseAsync):
    async def create(
        self,
        image: BinaryIO,
        source: str,
        facesize: Union[int, object] = sentinel,
        create_on_ha: Union[bool, object] = sentinel,
        create_on_junk: Union[bool, object] = sentinel,
        identify_asm: Union[bool, object] = sentinel,
    ) -> Response:
        data = request_form_processing(locals(), ["self", "image"])
        files = {"image": image}

        try:
            return await self.client.post(
                url="/v1/persons/", data=data, files=files
            )
        finally:
            await self.client.aclose()

    async def create_by_entry(
        self, id: int, create_on_ha: bool, create_on_junk: bool
    ) -> Response:
        data = request_dict_processing(locals(), ["self"])

        try:
            return await self.client.post(url="/v1/persons/entry/", json=data)
        finally:
            await self.client.aclose()

    async def reinit(self, id: int) -> Response:
        try:
            return await self.client.post(
                url="/v1/persons/reinit/", json={"id": id}
            )
        finally:
            await self.client.aclose()

    async def reinit_by_photo(
        self,
        pid: str,
        image: BinaryIO,
        source: str,
        facesize: Union[int, object] = sentinel,
        identify_asm: Union[bool, object] = sentinel,
        result: str = EntryResult.HA,
    ) -> Response:
        data = request_form_processing(locals(), ["self", "image", "pid"])
        files = {"image": image}

        try:
            return await self.client.post(
                url=f"/v1/persons/reinit/{pid}/", data=data, files=files
            )
        finally:
            await self.client.aclose()

    async def search(
        self, image: BinaryIO, identify_asm: bool = False
    ) -> Response:
        files = {"image": ("image", image, "image/jpeg")}
        data = {"identify_asm": str(identify_asm)}
        try:
            return await self.client.post(
                url="/v1/persons/search/", data=data, files=files
            )
        finally:
            await self.client.aclose()

    async def delete(self, pid: str) -> Response:
        try:
            return await self.client.delete(url=f"/v1/persons/{pid}/")
        finally:
            await self.client.aclose()
